---
name: Page actions
tags:
  - bottom of page actions
  - bottom page actions
  - primary action
  - default page actions

category: Structure
---

# Page actions

Page actions let merchants take key actions at the bottom of specific pages in the interface. This is important because sometimes the primary call to action is hard to access when merchants are at the bottom of a page.

**Problem**

Merchants need to be able to take important page actions, even after they’ve scrolled to the bottom of the page.

**Solution**

Page actions show at the bottom of pages so that merchants don’t need to scroll up to take important actions.

>**Not what you’re looking for?**
>
>* To create a regular call to action, [use the button component](/components/actions/button) to expand content in place in the page.
>* To let merchants take key actions at the bottom of specific pages in the interface, [use the page actions component](/components/structure/page-actions)

---

## Best practices

Page actions should:

- Include a single primary action on the right. It should be the same as the primary action that shows in the title bar at the top of the page.
- Include a maximum of two secondary actions, but doesn’t have to include any secondary actions.

---

## Content guidelines

### Call to action buttons

Buttons should be:

- Clear and predictable: merchants should be able to anticipate what will happen when they click a button. Never deceive a merchant by mislabeling a button.

<!-- usagelist -->
#### Do
- Create order
- Buy shipping label

#### Don't
- New order
- Buy
<!-- end -->

- Action-led: buttons should always lead with a strong verb that encourages action. To provide enough context to merchants use the {verb}+{noun} format on buttons except in the case of common actions like Save, Close, Cancel, or OK.

<!-- usagelist -->
#### Do
- Activate Apple Pay
- View shipping settings

#### Don't
- Try Apple Pay
- View your settings
<!-- end -->

- Scannable: avoid unnecessary words and articles such as the, an, or a.

<!-- usagelist -->
#### Do
Add menu item

#### Don't
Add a menu item
<!-- end -->

| Properties | Type | Description |
| ---------- | ---- | ----------- |
| primaryAction | DisableableAction | The primary action for the page |
| secondaryActions | ComplexAction[] | The secondary actions for the page |

## Examples

###  Default page actions

Used on a resource pages (e.g. an individual order page or a product page) to let merchants take key actions at the bottom of the page. Usually, the primary action is Save and the secondary action is Delete.

```jsx
<PageActions
  primaryAction={{
    content: 'Save',
  }}
  secondaryActions={[{
    content: 'Cancel',
  }]}
/>
```
